@@ -142,7 +142,7 @@ _http_new_chunk(struct httpio *io)
 	if (_download_getln(io->conn) == -1)
 		return (-1);
 
-	if (io->conn->buflen < 2 || !strchr(hexdigits, *p))
+	if (io->conn->buflen < 2 || !strchr(hexdigits, *io->conn->buf))
 		return (-1);
 
 	for (p = io->conn->buf; *p && !isspace(*p); ++p) {
@@ -815,6 +815,23 @@ _http_request(struct url *URL, const char *op, struct url_stat *us,
 	hdr_t h;
 	char hbuf[MAXHOSTNAMELEN + 7], *host;
 
+	char *no_proxy, *no_proxy_item;
+	size_t b, s;
+
+	if ((no_proxy = getenv("NO_PROXY")) != NULL) {
+		b = strlen(URL->host);
+		while ((no_proxy_item = strsep(&no_proxy, ",")) != NULL) {
+			s = strlen(no_proxy_item);
+			if (b > s && strcasecmp(URL->host + b - s,
+									no_proxy_item) == 0) {
+				/* disable proxy */
+				downloadFreeURL(purl);
+				purl = NULL;
+				break;
+			}
+		}
+	}
+
 	direct = CHECK_FLAG('d');
 	noredirect = CHECK_FLAG('A');
 	verbose = CHECK_FLAG('v');
